"""
Created on 2025-02-01

@author: wf
"""

import sys
from argparse import ArgumentParser
from ngwidgets.cmd import WebserverCmd
from velorail.webserver import VeloRailWebServer


class VeloRailCmd(WebserverCmd):
    """
    command line handling for velorail
    """

    def __init__(self):
        """
        constructor
        """
        config = VeloRailWebServer.get_config()
        WebserverCmd.__init__(self, config, VeloRailWebServer, DEBUG)
        pass

    def getArgParser(self, description: str, version_msg) -> ArgumentParser:
        """
        override the default argparser call
        """
        parser = super().getArgParser(description, version_msg)
        parser.add_argument(
            "-v",
            "--verbose",
            action="store_true",
            help="show verbose output [default: %(default)s]",
        )
        parser.add_argument(
            "-rp",
            "--root_path",
            default=VeloRailWebServer.examples_path(),
            help="path to velorail files [default: %(default)s]",
        )
        return parser


def main(argv: list = None):
    """
    main call
    """
    cmd = VeloRailCmd()
    exit_code = cmd.cmd_main(argv)
    return exit_code


DEBUG = 0
if __name__ == "__main__":
    if DEBUG:
        sys.argv.append("-d")
    sys.exit(main())



"""
Created on 2025-02-01

@author: wf
"""
import velorail
from dataclasses import dataclass


@dataclass
class Version:
    """
    Version handling for velorail
    """

    name = "velorail"
    version = velorail.__version__
    date = "2025-02-01"
    updated = "2025-02-01"
    description = "Multimodal bike and train route planning support"

    authors = "Wolfgang Fahl"

    doc_url = "https://wiki.bitplan.com/index.php/velorail"
    chat_url = "https://github.com/WolfgangFahl/velorail/discussions"
    cm_url = "https://github.com/WolfgangFahl/velorail"

    license = f"""Copyright 2025 contributors. All rights reserved.

  Licensed under the Apache License 2.0
  http://www.apache.org/licenses/LICENSE-2.0

  Distributed on an "AS IS" basis without warranties
  or conditions of any kind, either express or implied."""

    longDescription = f"""{name} version {version}
{description}

  Created by {authors} on {date} last updated {updated}"""



"""
Created on 2025-02-01

@author: wf
"""

from ngwidgets.basetest import Basetest
from velorail.version import Version


class TestVersion(Basetest):
    """
    test Version
    """

    def setUp(self, debug=True, profile=True):
        Basetest.setUp(self, debug=debug, profile=profile)

    def test_Version(self):
        """
        test Version object - effectively only testing the test infrastructure
        """
        version=Version()
        self.assertIsNotNone(version)